
# Wrappers
from pyHiGHS.linprog import highs_wrapper, linprog_mps

# Constants
from pyHiGHS.linprog import (
    HIGHS_CONST_I_INF,
    HIGHS_CONST_INF,
    HIGHS_CONST_TINY,
    HIGHS_CONST_ZERO,
    HIGHS_THREAD_LIMIT,
    ML_NONE,
    ML_VERBOSE,
    ML_DETAILED,
    ML_MINIMAL,
    SOLVER_OPTION_CHOOSE,
    SOLVER_OPTION_SIMPLEX,
    SOLVER_OPTION_IPM,
)



import numpy as np
from scipy.sparse import csc_matrix

from pyHiGHS import highs_wrapper
from pyHiGHS import (
    HIGHS_CONST_INF,
    HIGHS_CONST_TINY,
)

if __name__ == '__main__':

    #c = np.array([-3, -2]).astype('double')
    #A = csc_matrix(np.array([[2, 1], [1, 1], [1, 0]])).astype('double')
    #rhs = np.array([10, 8, 4]).astype('double')
    #lhs= np.array([-HIGHS_CONST_INF]*3).astype('double')
    #lb= np.array([0, 0]).astype('double')
    #ub= np.array([HIGHS_CONST_INF]*2).astype('double')

    #c = np.array([-1, 1]).astype('double')
    #A = csc_matrix(np.array([[1, 0], [0, 1]])).astype('double')
    #lhs = np.array([-np.inf, 2]).astype('double')
    #rhs = np.array([1, 2]).astype('double')
    #lb = np.array([1, 2]).astype('double')
    #ub = np.array([1, 2]).astype('double')

    #c = np.array([-1, -2]).astype('double')
    #A = csc_matrix(np.empty((0, c.size))).astype('double')
    #lhs = np.array([]).astype('double')
    #rhs = np.array([]).astype('double')
    #lb = np.array([0, 0]).astype('double')
    #ub = np.array([np.inf, np.inf]).astype('double')

    c = np.array([-4, 1]).astype('double')
    A = csc_matrix(np.array([[7, -2], [0, 1], [2, -2]])).astype('double')
    lhs = np.array([-np.inf, -np.inf]).astype('double')
    rhs = np.array([14, 0, 3]).astype('double')
    lb = np.array([2, 0]).astype('double')
    ub = np.array([2, None]).astype('double')

    res = highs_wrapper(c, A, rhs, lhs, lb, ub, {'sense':1, 'presolve':False, 'solver':'simplex'})
    print(res)



'''Try out simple problem that is failing.'''

import unittest

import numpy as np
from pyHiGHS import highs_wrapper

class TestHiGHS(unittest.TestCase):

    def test_simple_presolve(self):

        c = np.array([-1, 1], dtype='double')
        A = np.array([
            [1, 0],
            [0, 1],
        ], dtype='double')
        lhs = np.array([-np.inf, 2.], dtype='double')
        rhs = np.array([1., 2.], dtype='double')
        lb = np.array([1., 2.], dtype='double')
        ub = np.array([1., 2.], dtype='double')

        options = {'presolve': True, 'method': 'simplex'}
        with self.assertRaises(RuntimeError):
            res = highs_wrapper(c, A, rhs, lhs, lb, ub, options=options)

        options['presolve'] = False
        res = highs_wrapper(c, A, rhs, lhs, lb, ub, options=options)
        self.assertEqual(res['col_value'].tolist(), [1, 2])

if __name__ == '__main__':
    unittest.main()
